@@ -28,6 +28,8 @@ def main():
         be accessible through the package's scope).  In all other cases,
         only tests accessible from introspection of the object will be
         loaded."""))
+    parser.add_argument('-V', '--version', action='store_true', default=False,
+        help="Print the version of Green and Python and exit.")
     parser.add_argument('-d', '--debug', action='count', default=0,
         help=("Enable internal debugging statements.  Implies --logging.  Can "
         "be specified up to three times for more debug output."))
@@ -54,6 +56,12 @@ def main():
     # that they want, though, so we'll just leave ours.
     sys.argv = sys.argv[:1]
 
+    # Just print version and exit?
+    if args.version:
+        from green.version import pretty_version
+        print(pretty_version())
+        sys.exit()
+
     # Handle logging options
 
     if args.debug:
@@ -106,10 +114,13 @@ def main():
         cov.stop()
         omit = [
             '*/test*',
-            '*site-packages*/green*',
+            '*site-packages/pkg_resources*',
+            '*Python.framework*',
             tempfile.gettempdir() + '*']
         if 'termstyle' not in args.target:
             omit.append('*/termstyle*')
+        if (args.target != 'green') and (not args.target.startswith('green.')):
+            omit.append('*site-packages*/green*')
         cov.report(file=stream, omit=omit)
     sys.exit(not result.wasSuccessful())
 
